@@ -1,17 +1,20 @@
-pca.nipals <- function (data, ncomps = 1, Iters = 500, tol = 1e-08) {
+pca.nipals <- function(data, ncomps = 1, Iters = 500, start.vec = NULL, tol = 1e-08) {
   ws.ncomps <- Scores.ncomps <- ws.iters <- Scores.iters <- NULL
   loading.space <- scores.space <- list()
   X <- scale(data, center = TRUE, scale = FALSE)
-  y. <- X[, sample(1:ncol(X), 1)]
   data.xa. <- X
-  y. <- data.xa.[, sample(1:ncol(data.xa.), 1)]
+  if(is.null(start.vec)) {
+    y. <- data.xa.[, sample(1:ncol(data.xa.), 1)]
+  } else {
+    y. <- start.vec
+  }
   data.xa. <- as.matrix(X)
   for (i in 1:ncomps) {
-    for (a in c(1:Iters)){
+    for (a in c(1:Iters)) {
       y. <- y.
       (ws.pre <- as.matrix((t(data.xa.) %*% y.)))
       (Ws.norm <- (crossprod(t(data.xa.) %*% y.)))
-      (ws. <- (ws.pre / sqrt(Ws.norm)[1]))
+      (ws. <- (ws.pre/sqrt(Ws.norm)[1]))
       (Scores <- (data.xa. %*% ws.))
       (Conv <- t(y. - Scores) %*% (y. - Scores))
       ws.iters <- cbind(ws.iters, ws.)
@@ -29,9 +32,8 @@ pca.nipals <- function (data, ncomps = 1, Iters = 500, tol = 1e-08) {
     ws.ncomps <- cbind(ws.ncomps, ws.f)
     Scores.ncomps <- cbind(Scores.ncomps, Scores.f)
     Results <- list(Loadings = ws.ncomps, Scores = Scores.ncomps, 
-                    Loading.Space = loading.space, 
-                    Score.Space = scores.space)
+                    Loading.Space = loading.space, Score.Space = scores.space)
   }
   class(Results) <- "npca"
   Results
-}
\ No newline at end of file
+}
